@@ -13,6 +13,12 @@ return ['routes' => [
 		'verb' => 'GET',
 		'postfix' => 'welcome',
 	],
+	[
+		'name' => 'page#create',
+		'url' => '/new',
+		'verb' => 'GET',
+		'postfix' => 'new',
+	],
 	[
 		'name' => 'page#index',
 		'url' => '/note/{id}',
@@ -28,6 +34,11 @@ return ['routes' => [
 		'url' => '/notes',
 		'verb' => 'GET',
 	],
+	[
+		'name' => 'notes#dashboard',
+		'url' => '/notes/dashboard',
+		'verb' => 'GET',
+	],
 	[
 		'name' => 'notes#get',
 		'url' => '/notes/{id}',
