@@ -1,13 +1,13 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "The last viewed note cannot be accessed. ",
+    "Notes" : "Notes",
     "Error" : "Error",
     "New note" : "New note",
-    "Notes" : "Notes",
     "Distraction-free notes and writing" : "Distraction-free notes and writing",
-    "Settings" : "Settings",
     "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
+    "Settings" : "Settings",
+    "No notes yet" : "No notes yet",
     "All notes" : "All notes",
     "Categories" : "Categories",
     "Today" : "Today",
@@ -19,8 +19,8 @@ OC.L10N.register(
     "Remove from favorites" : "Remove from favourites",
     "Add to favorites" : "Add to favourites",
     "Details" : "Details",
-    "Preview" : "Preview",
     "Edit" : "Edit",
+    "Preview" : "Preview",
     "Category" : "Category",
     "Uncategorized" : "Uncategorised",
     "Saving failed!" : "Saving failed!",
