@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Oharrak",
     "Reading notes from filesystem has failed." : "Fitxategi-sistemaren ohar-irakurketak huts egin du.",
     "Error" : "Errorea",
     "New note" : "Ohar berria",
-    "Notes" : "Oharrak",
     "Distraction-free notes and writing" : "Distrakziorik gabeko oharrak eta idazkiak",
     "Please see Nextcloud server log for details." : "Ikus Nextcloud zerbitzari-egunkaria xehetasunak eskuratzeko.",
     "Deleted {title}" : "{title} ezabatuta",
-    "Deleted {number} notes" : "{number} ohar ezabatuta",
     "Undo Delete" : "Desegin ezabatzea",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko oharrak daude. Orrialdetik irtetean aldaketa guztiak galduko dira!",
     "Settings" : "Ezarpenak",
     "Folder to store your notes" : "Zure oharrak gordetzeko karpeta",
     "path to notes" : "oharretara bidea",
     "File extension for new notes" : "Ohar berrien fitxategi-luzapena",
+    "No notes yet" : "Ez dago oharrik",
     "All notes" : "Ohar guztiak",
     "Categories" : "Kategoriak",
-    "No search result for “{search}” in {category}" : "Ez dago emaitzarik “{search}” bilaketarentzat {category} kategorian",
-    "No search result for “{search}”" : "Ez dago emaitzarik “{search}” bilaketarentzat",
     "Loading …" : "Kargatzen...",
-    "Search result for “{search}” in {category}" : "“{search}” bilaketaren emaitza {category} kategorian",
-    "Search result for “{search}”" : "“{search}” bilaketaren emaitza",
     "Today" : "Gaur",
     "Yesterday" : "Atzo",
     "This week" : "Aste honetan",
