@@ -1,26 +1,20 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "آخرین یادداشت مشاهده شده قابل دسترسی نیست.",
-    "The notes folder is not accessible: %s" : "پوشه یادداشت ها در دسترس نیست: %s",
+    "Notes" : "یادداشت ها",
     "Error" : "خطا",
     "New note" : "یادداشت جدید",
-    "Notes" : "یادداشت ها",
     "Distraction-free notes and writing" : "یادداشت ها و نوشتن بدون حواس پرتی",
-    "Settings" : "تنظیمات",
     "Deleted {title}" : "حذف {عنوان}",
-    "Please chose a valid path in {label} (bottom left corner)." : "لطفاً یک مسیر معتبر را در {label} (گوشه پایین سمت چپ) انتخاب کنید.",
     "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشتهای ذخیره نشده وجود دارد. ترک صفحه باعث می شود همه تغییرات از بین بروند!",
+    "Settings" : "تنظیمات",
     "Folder to store your notes" : "پوشه برای ذخیره یادداشت های خود",
     "path to notes" : "مسیر یادداشت ها",
     "File extension for new notes" : "پسوند پرونده برای یادداشتهای جدید",
+    "No notes yet" : "هنوز هیچ یادداشتی وجود ندارد",
     "All notes" : "همه یادداشت ها",
     "Categories" : "دسته بندی ها",
-    "No search result for “{search}” in {category}" : "نتیجه جستجو برای \"{search}\" در {گروه}",
-    "No search result for “{search}”" : "نتیجه جستجو برای \"{search}\"",
     "Loading …" : "بارگذاری …",
-    "Search result for “{search}” in {category}" : "نتیجه جستجو برای \"{search}\" در {دسته}",
-    "Search result for “{search}”" : "نتیجه جستجو برای \"{search}\"",
     "Today" : "Today",
     "Yesterday" : "دیروز",
     "This week" : "این هفته",
@@ -34,8 +28,8 @@ OC.L10N.register(
     "Empty note" : "یادداشت خالی",
     "Write …" : "نوشتن …",
     "Details" : "جزئیات",
-    "Preview" : "پیش نمایش",
     "Edit" : "ویرایش کردن",
+    "Preview" : "پیش نمایش",
     "Exit full screen" : "خروج از تمام صفحه",
     "Full screen" : "تمام صفحه",
     "Save failed. Click to retry." : "ذخیره نشد. برای امتحان دوباره کلیک کنید",
