@@ -1,21 +1,18 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Muistiinpanot",
     "Error" : "Virhe",
     "New note" : "Uusi muistiinpano",
-    "Notes" : "Muistiinpanot",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
     "Settings" : "Asetukset",
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
     "path to notes" : "polku muistiinpanoihin",
     "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
+    "No notes yet" : "Ei muistiinpanoja",
     "All notes" : "Kaikki muistiinpanot",
     "Categories" : "Luokat",
-    "No search result for “{search}” in {category}" : "Ei tuloksia haulla “{search}” luokasta {category}",
-    "No search result for “{search}”" : "Ei tuloksia haulla “{search}”",
     "Loading …" : "Ladataan…",
-    "Search result for “{search}” in {category}" : "Tulos haulle “{search}” luokasta {category}",
-    "Search result for “{search}”" : "Tulos haulle “{search}”",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
     "This week" : "Tällä viikolla",
