@@ -1,25 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Bilješke",
+    "Reading notes from filesystem has failed." : "Čitanje bilješki iz datotečnog sustava nije uspjelo.",
     "Error" : "Pogreška",
     "New note" : "Nova bilješka",
-    "Notes" : "Bilješke",
     "Distraction-free notes and writing" : "Bilješke i pisanje bez ometanja",
+    "Please see Nextcloud server log for details." : "Pojedinosti potražite u zapisniku Nextcloudovog poslužitelja.",
     "Deleted {title}" : "Izbrisano {title}",
-    "Deleted {number} notes" : "Izbrisane bilješke: {number}",
     "Undo Delete" : "Vrati izbrisano",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Postoje nespremljene bilješke. Ako napustite stranicu, odbacit ćete sve promjene!",
     "Settings" : "Postavke",
     "Folder to store your notes" : "Mapa za spremanje bilješki",
     "path to notes" : "put do bilješki",
     "File extension for new notes" : "Ekstenzija datoteke za nove bilješke",
+    "No notes yet" : "Još nema bilješki",
     "All notes" : "Sve bilješke",
     "Categories" : "Kategorije",
-    "No search result for “{search}” in {category}" : "Nema rezultata pretraživanja za „{search}” u {category}",
-    "No search result for “{search}”" : "Nema rezultata pretraživanja za „{search}”",
     "Loading …" : "Učitavanje…",
-    "Search result for “{search}” in {category}" : "Rezultat pretraživanja za „{search}” u {category}",
-    "Search result for “{search}”" : "Rezultat pretraživanja za „{search}”",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
     "This week" : "Ovaj tjedan",
@@ -35,6 +33,7 @@ OC.L10N.register(
     "Empty note" : "Prazna bilješka",
     "Write …" : "Napiši...",
     "Details" : "Pojedinosti",
+    "CTRL + /" : "CTRL + /",
     "Edit" : "Uredi",
     "Preview" : "Pretpregled",
     "Exit full screen" : "Zatvori prikaz preko cijelog zaslona",
@@ -58,13 +57,19 @@ OC.L10N.register(
     "iOS app" : "Aplikacija za iOS",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Započnite pisati bilješku klikom na „{newnote}” u navigaciji aplikacije.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Možete kreirati potkategorije korištenjem \"/\" kao odjeljivača između nadređene kategorije i potkategorije, npr. “{parent}/{sub}”.",
+    "Note not found." : "Bilješka nije pronađena.",
+    "Note is locked." : "Bilješka je zaključana.",
+    "Insufficient storage." : "Nedovoljno prostora za pohranu.",
     "See JavaScript console and server log for details." : "Pojedinosti potražite u JavaScript konzoli i zapisniku poslužitelja.",
     "Updating settings has failed." : "Ažuriranje postavki nije uspjelo.",
+    "Error from Nextcloud server: {msg}" : "Pogreška Nextcloudovog poslužitelja: {msg}",
     "Fetching notes has failed." : "Dohvaćanje bilješki nije uspjelo.",
     "Fetching note {id} has failed." : "Dohvaćanje bilješke {id} nije uspjelo.",
+    "Refreshing note {id} has failed." : "Osvježavanje bilješke {id} nije uspjelo.",
     "Renaming note {id} has failed." : "Preimenovanje bilješke {id} nije uspjelo.",
     "Creating new note has failed." : "Stvaranje nove bilješke nije uspjelo.",
     "Saving note {id} has failed." : "Spremanje bilješke {id} nije uspjelo.",
+    "Updating title for note {id} has failed." : "Ažuriranje naslova bilješke {id} nije uspjelo.",
     "Undo delete has failed for note {title}." : "Nije uspjelo vraćanje izbrisanog za bilješku {title}.",
     "Deleting note {id} has failed." : "Brisanje bilješke {id} nije uspjelo.",
     "Toggling favorite for note {id} has failed." : "Postavljanje favorita za bilješku {id} nije uspjelo.",
