@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Заметки",
     "Reading notes from filesystem has failed." : "Чтение заметок из файловой системы не удалось",
     "Error" : "Ошибка",
     "New note" : "Новая заметка",
-    "Notes" : "Заметки",
     "Distraction-free notes and writing" : "Простые заметки и записки",
     "Please see Nextcloud server log for details." : "Пожалуйста, обратитесь к логам сервера Nextcloud за деталями",
     "Deleted {title}" : "Заметка {tilte} удалена",
-    "Deleted {number} notes" : "Удалено заметок: {number}",
     "Undo Delete" : "Отменить удаление",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Заметки не сохранены. Если покинуть страницу, все изменения будут удалены.",
     "Settings" : "Параметры",
     "Folder to store your notes" : "Папка для хранения заметок",
     "path to notes" : "путь к заметкам",
     "File extension for new notes" : "Расширения файла для новых заметок",
+    "No notes yet" : "Нет ни одной заметки",
     "All notes" : "Все заметки",
     "Categories" : "Категории",
-    "No search result for “{search}” in {category}" : "Ничего не найдено по запросу «{search}» в категории {category}",
-    "No search result for “{search}”" : "По запросу «{search}» ничего не найдено",
     "Loading …" : "Загрузка ...",
-    "Search result for “{search}” in {category}" : "Результаты поиска по запросу «{search}» в категории {category}",
-    "Search result for “{search}”" : "Результаты поиска по запросу «{search}»",
     "Today" : "Сегодня",
     "Yesterday" : "Вчера",
     "This week" : "Эта неделя",
