@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Beležka",
     "Reading notes from filesystem has failed." : "Branje zabeležk z datotečnega sistema je spodletelo.",
     "Error" : "Napaka",
     "New note" : "Nova zabeležka",
-    "Notes" : "Beležka",
     "Distraction-free notes and writing" : "Enostavno beleženje in zapisovanje",
     "Please see Nextcloud server log for details." : "Za več podrobnosti si oglejte dnevniški zapis strežnika Nextcloud.",
     "Deleted {title}" : "Izbrisano {title}",
-    "Deleted {number} notes" : "Izbrisane zabeležke: {number} ",
     "Undo Delete" : "Razveljavi brisanje",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Zabeležke še niso shranjene. Če zapustite stran, bodo spremembe izgubljene!",
     "Settings" : "Nastavitve",
     "Folder to store your notes" : "Mapa za shranjevanje zabeležk",
     "path to notes" : "pot do mape",
     "File extension for new notes" : "Privzeta pripona datotek za nove zabeležke",
+    "No notes yet" : "Ni še dodane nobene zabeležke",
     "All notes" : "Vse zabeležke",
     "Categories" : "Kategorije",
-    "No search result for “{search}” in {category}" : "Ni zadetkov iskanja za niz » {search} « v kategoriji {category}",
-    "No search result for “{search}”" : "Ni zadetkov iskanja za niz » {search} «",
     "Loading …" : "Poteka nalaganje …",
-    "Search result for “{search}” in {category}" : "Zadetki iskanja za niz » {search} « v kategoriji {category}",
-    "Search result for “{search}”" : "Zadetki iskanja za niz » {search} «",
     "Today" : "Danes",
     "Yesterday" : "Včeraj",
     "This week" : "Ta teden",
