@@ -1,27 +1,23 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "Anteckningar",
     "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
     "Error" : "Fel",
     "New note" : "Ny anteckning",
-    "Notes" : "Anteckningar",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
     "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
     "Deleted {title}" : "Raderad {title}",
-    "Deleted {number} notes" : "Borttagna {number} anteckningar",
     "Undo Delete" : "Ångra radering",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "Settings" : "Inställningar",
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "path to notes" : "sökväg till anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
+    "No notes yet" : "Inga anteckningar än",
     "All notes" : "Alla anteckningar",
     "Categories" : "Kategorier",
-    "No search result for “{search}” in {category}" : "Inget sökresultat för “{search}” i {category}",
-    "No search result for “{search}”" : "Inget sökresultat för “{search}”",
     "Loading …" : "Läser in ...",
-    "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
-    "Search result for “{search}”" : "Sökresultat för “{search}”",
     "Today" : "Idag",
     "Yesterday" : "Igår",
     "This week" : "Denna vecka",
