@@ -1,25 +1,21 @@
 OC.L10N.register(
     "notes",
     {
+    "Notes" : "笔记",
     "Error" : "错误",
     "New note" : "新建笔记",
-    "Notes" : "笔记",
     "Distraction-free notes and writing" : "无干扰的笔记和写作",
     "Deleted {title}" : "已删除 {title}",
-    "Deleted {number} notes" : "已删除 {number} 条笔记",
     "Undo Delete" : "撤销删除",
     "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
     "Settings" : "设置",
     "Folder to store your notes" : "保存您的笔记的文件夹",
     "path to notes" : "笔记的路径",
     "File extension for new notes" : "新笔记的文件扩展名",
+    "No notes yet" : "还没有便签",
     "All notes" : "所有笔记",
     "Categories" : "分类",
-    "No search result for “{search}” in {category}" : "在 {category} 中没有关于 “{search}”的搜索结果",
-    "No search result for “{search}”" : "没有关于“{search}”的搜索结果",
     "Loading …" : "正在加载…",
-    "Search result for “{search}” in {category}" : "在{category}中搜索 “{search}”的结果",
-    "Search result for “{search}”" : "搜索 “{search}”的结果",
     "Today" : "今天",
     "Yesterday" : "昨天",
     "This week" : "本周",
