@@ -1,25 +1,20 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "無法打開最近一次檢視的筆記",
-    "The notes folder is not accessible: %s" : "無法打開筆記資料夾：%s",
+    "Notes" : "筆記",
     "Error" : "錯誤",
     "New note" : "新筆記",
-    "Notes" : "筆記",
     "Distraction-free notes and writing" : "可以讓你專心記錄不受干擾的筆記應用",
-    "Settings" : "設定",
     "Deleted {title}" : "已刪除 {title}",
     "There are unsaved notes. Leaving the page will discard all changes!" : "有未儲存內容。離開頁面會有遺失資料風險。",
+    "Settings" : "設定",
     "Folder to store your notes" : "儲存筆記的資料夾",
     "path to notes" : "筆記的路徑",
     "File extension for new notes" : "筆記副檔名",
+    "No notes yet" : "尚沒有筆記",
     "All notes" : "全部筆記",
     "Categories" : "分類",
-    "No search result for “{search}” in {category}" : "在 {category} 分類中搜尋不到 “{search}”",
-    "No search result for “{search}”" : "搜尋不到 “{search}”",
     "Loading …" : "載入中 ...",
-    "Search result for “{search}” in {category}" : "在 {category} 分類搜尋 “{search}” 結果",
-    "Search result for “{search}”" : "搜尋 “{search}” 的結果",
     "Today" : "今天",
     "Yesterday" : "昨天",
     "This week" : "本週",
@@ -33,8 +28,8 @@ OC.L10N.register(
     "Empty note" : "無內容",
     "Write …" : "由此寫入...標題",
     "Details" : "詳細資料",
-    "Preview" : "預覽",
     "Edit" : "退出",
+    "Preview" : "預覽",
     "Exit full screen" : "退出全螢幕",
     "Full screen" : "全螢幕",
     "Save failed. Click to retry." : "儲存失敗。按一下再試。",
